==> vlc-0.5.0.tar.bz2: vlc-0.5.0/modules/gui/win32/messages.h <==
/*****************************************************************************
 * messages.h: log window
 *****************************************************************************
 * Copyright (C) 2002 VideoLAN
 *
 * Authors: Olivier Teuliere <ipkiss@via.ecp.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 *****************************************************************************/

#ifndef messagesH
#define messagesH
//---------------------------------------------------------------------------
#include <Classes.hpp>
#include <Controls.hpp>
#include <StdCtrls.hpp>
#include <Forms.hpp>
#include <ComCtrls.hpp>
#include <Menus.hpp>
//---------------------------------------------------------------------------
class TMessagesDlg : public TForm
{
__published:	// IDE-managed Components
    TRichEdit *RichEditMessages;
    TButton *ButtonOK;
    void __fastcall ButtonOKClick( TObject *Sender );
    void __fastcall FormHide( TObject *Sender );
    void __fastcall FormShow( TObject *Sender );
private:	// User declarations
    intf_thread_t *p_intf;
public:		// User declarations
    __fastcall TMessagesDlg( TComponent* Owner, intf_thread_t *_p_intf );
    void __fastcall UpdateLog();
};
//---------------------------------------------------------------------------
#endif

==> vlc-0.5.2.tar.bz2: vlc-0.5.2/modules/gui/win32/messages.h <==
/*****************************************************************************
 * messages.h: log window
 *****************************************************************************
 * Copyright (C) 2002 VideoLAN
 *
 * Authors: Olivier Teuliere <ipkiss@via.ecp.fr>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.
 *****************************************************************************/

#ifndef messagesH
#define messagesH
//---------------------------------------------------------------------------
#include <Classes.hpp>
#include <Controls.hpp>
#include <StdCtrls.hpp>
#include <Forms.hpp>
#include <ComCtrls.hpp>
#include <Menus.hpp>
//---------------------------------------------------------------------------
class TMessagesDlg : public TForm
{
__published:	// IDE-managed Components
    TRichEdit *RichEditMessages;
    TButton *ButtonOK;
    TPopupMenu *PopupMenu1;
    TMenuItem *PopupCopyText;
    void __fastcall ButtonOKClick( TObject *Sender );
    void __fastcall FormHide( TObject *Sender );
    void __fastcall FormShow( TObject *Sender );
    void __fastcall PopupCopyTextClick( TObject *Sender );
private:	// User declarations
    intf_thread_t *p_intf;
public:		// User declarations
    __fastcall TMessagesDlg( TComponent* Owner, intf_thread_t *_p_intf );
    void __fastcall UpdateLog();
};
//---------------------------------------------------------------------------
#endif
